Matt Daemon
===========================

A lightweight HTTP daemon for serving static files.
With Matt Daemon, there are no surprises. He just serves.

Installation
------------

This is a `Python`_ module available through the `PyPI`_.

Before installing, `download and install Python`_. We recommend
installing version 3.5+ of Python.

Installation is done using the ``pip install`` command:

.. code:: bash

    $ pip install matt-daemon

For more info, see `pip install`_ docs.

Get Started
-----------

To start the Matt Daemon, all you need to do is run the following command:

.. code:: bash

    $ matt-daemon


.. _Python: https://python.org
.. _PyPI: https://pypi.python.org/
.. _download and install Python: https://www.python.org/downloads/
.. _pip install: https://docs.python.org/3/installing/index.html
